@@ -71,7 +71,7 @@ function(object, x, ext=NULL, filename='', ...) {
 			inmem <- FALSE
 			if  (filename == '') {
 				filename <- rasterTmpFile()
-				if (getOption('verbose')) { cat('writing raster to:', filename)	}						
+				if (getOption('verbose')) { message('writing raster to:', filename)	}						
 			}
 			out <- writeStart(out, filename=filename, ... )
 		}
